@@ -12,6 +12,7 @@
 #include <meta/keybindings.h>
 #include <meta/meta-context.h>
 #include <meta/util.h>
+#include <meta/meta-window-config.h>
 #include <meta/meta-window-group.h>
 
 #include <systemd/sd-daemon.h>
@@ -24,6 +25,8 @@
 #include "kiosk-app-system.h"
 #include "kiosk-window-tracker.h"
 #include "kiosk-shell-introspect-service.h"
+#include "kiosk-shell-screenshot-service.h"
+#include "kiosk-window-config.h"
 
 #include "org.gnome.DisplayManager.Manager.h"
 
@@ -46,6 +49,8 @@ struct _KioskCompositor
         KioskAppSystem              *app_system;
         KioskWindowTracker          *tracker;
         KioskShellIntrospectService *introspect_service;
+        KioskShellScreenshotService *screenshot_service;
+        KioskWindowConfig           *kiosk_window_config;
 };
 
 enum
@@ -59,6 +64,8 @@ static guint signals[NUMBER_OF_SIGNALS] = { 0, };
 G_DEFINE_TYPE (KioskCompositor, kiosk_compositor, META_TYPE_PLUGIN)
 
 static void kiosk_compositor_dispose (GObject *object);
+static gboolean kiosk_compositor_wants_window_fullscreen (KioskCompositor *self,
+                                                          MetaWindow      *window);
 
 static void
 kiosk_compositor_dispose (GObject *object)
@@ -218,16 +225,51 @@ neuter_builtin_keybindings (KioskCompositor *self)
         }
 }
 
+static void
+kiosk_compositor_on_window_configure (MetaWindow       *window,
+                                      MetaWindowConfig *window_config,
+                                      gpointer          user_data)
+{
+        KioskCompositor *self = KIOSK_COMPOSITOR (user_data);
+        gboolean fullscreen;
+
+        if (!meta_window_config_get_is_initial (window_config)) {
+                g_debug ("KioskCompositor: Ignoring configure for window: %s",
+                         meta_window_get_description (window));
+                return;
+        }
+
+        g_debug ("KioskCompositor: configure window: %s", meta_window_get_description (window));
+
+        fullscreen = kiosk_compositor_wants_window_fullscreen (self, window);
+        meta_window_config_set_is_fullscreen (window_config, fullscreen);
+        kiosk_window_config_update_window (self->kiosk_window_config,
+                                           window,
+                                           window_config);
+}
+
+static void
+kiosk_compositor_on_window_created (MetaDisplay *display,
+                                    MetaWindow  *window,
+                                    gpointer     user_data)
+{
+        g_signal_connect (window, "configure",
+                          G_CALLBACK (kiosk_compositor_on_window_configure),
+                          user_data);
+}
+
 static void
 kiosk_compositor_start (MetaPlugin *plugin)
 {
         KioskCompositor *self = KIOSK_COMPOSITOR (plugin);
         g_autoptr (GError) error = NULL;
+        MetaDisplay *display = meta_plugin_get_display (META_PLUGIN (self));
+        MetaCompositor *compositor = meta_display_get_compositor (display);
 
-        g_set_weak_pointer (&self->display, meta_plugin_get_display (META_PLUGIN (self)));
+        g_set_weak_pointer (&self->display, display);
         g_set_weak_pointer (&self->context, meta_display_get_context (self->display));
         g_set_weak_pointer (&self->backend, clutter_get_default_backend ());
-        g_set_weak_pointer (&self->stage, meta_get_stage_for_display (self->display));
+        g_set_weak_pointer (&self->stage, CLUTTER_ACTOR (meta_compositor_get_stage (compositor)));
 
         clutter_actor_show (self->stage);
 
@@ -248,8 +290,11 @@ kiosk_compositor_start (MetaPlugin *plugin)
         self->input_sources_manager = kiosk_input_sources_manager_new (self);
         self->app_system = kiosk_app_system_new (self);
         self->tracker = kiosk_window_tracker_new (self, self->app_system);
+        self->kiosk_window_config = kiosk_window_config_new ();
         self->introspect_service = kiosk_shell_introspect_service_new (self);
         kiosk_shell_introspect_service_start (self->introspect_service, &error);
+        self->screenshot_service = kiosk_shell_screenshot_service_new (self);
+        kiosk_shell_screenshot_service_start (self->screenshot_service, &error);
 
         if (error != NULL) {
                 g_debug ("KioskCompositor: Could not start D-Bus service: %s", error->message);
@@ -261,6 +306,11 @@ kiosk_compositor_start (MetaPlugin *plugin)
                                                       self->cancellable,
                                                       KIOSK_OBJECT_CALLBACK (register_session),
                                                       NULL);
+
+        g_signal_connect_object (self->display, "window-created",
+                                 G_CALLBACK (kiosk_compositor_on_window_created),
+                                 self,
+                                 G_CONNECT_DEFAULT);
 }
 
 static void
@@ -337,6 +387,15 @@ static gboolean
 kiosk_compositor_wants_window_above (KioskCompositor *self,
                                      MetaWindow      *window)
 {
+        gboolean set_above;
+
+        if (kiosk_window_config_get_boolean_for_window (self->kiosk_window_config,
+                                                        window,
+                                                        "set-above",
+                                                        &set_above))
+                return set_above;
+
+        /* If not specified in the config, use the heuristics */
         if (meta_window_is_screen_sized (window)) {
                 return FALSE;
         }
@@ -368,23 +427,14 @@ kiosk_compositor_map (MetaPlugin      *plugin,
 
         window = meta_window_actor_get_meta_window (actor);
 
-        if (kiosk_compositor_wants_window_fullscreen (self, window)) {
+        if (meta_window_is_fullscreen (window)) {
                 g_debug ("KioskCompositor: Mapping window that does need to be fullscreened");
-                meta_window_make_fullscreen (window);
                 easing_duration = 3000;
         } else {
-                ClutterActor *window_group;
-
                 g_debug ("KioskCompositor: Mapping window that does not need to be fullscreened");
-                window_group = meta_get_top_window_group_for_display (self->display);
 
-                if (kiosk_compositor_wants_window_above (self, window)) {
-                        g_object_ref (G_OBJECT (actor));
-                        clutter_actor_remove_child (clutter_actor_get_parent (CLUTTER_ACTOR (actor)), CLUTTER_ACTOR (actor));
-                        clutter_actor_add_child (window_group, CLUTTER_ACTOR (actor));
-                        clutter_actor_set_child_above_sibling (window_group, CLUTTER_ACTOR (actor), NULL);
-                        g_object_unref (G_OBJECT (actor));
-                }
+                if (kiosk_compositor_wants_window_above (self, window))
+                        meta_window_make_above (window);
 
                 easing_duration = 500;
         }
@@ -502,20 +552,6 @@ kiosk_compositor_confirm_display_change (MetaPlugin *plugin)
         meta_plugin_complete_display_change (META_PLUGIN (self), TRUE);
 }
 
-static const MetaPluginInfo info = {
-        .name        = "GNOME Kiosk",
-        .version     = VERSION,
-        .author      = "Various",
-        .license     = "GPLv2+",
-        .description = "Provides Kiosk compositor plugin for mutter"
-};
-
-static const MetaPluginInfo *
-kiosk_compositor_plugin_info (MetaPlugin *plugin)
-{
-        return &info;
-}
-
 static MetaCloseDialog *
 kiosk_compositor_create_close_dialog (MetaPlugin *plugin,
                                       MetaWindow *window)
@@ -566,8 +602,6 @@ kiosk_compositor_class_init (KioskCompositorClass *compositor_class)
 
         plugin_class->confirm_display_change = kiosk_compositor_confirm_display_change;
 
-        plugin_class->plugin_info = kiosk_compositor_plugin_info;
-
         plugin_class->create_close_dialog = kiosk_compositor_create_close_dialog;
         plugin_class->create_inhibit_shortcuts_dialog = kiosk_compositor_create_inhibit_shortcuts_dialog;
 
